add_table.RdExtends the functionality of the officer package by easing the creation of word documents. Tables will be added sequentually. A page break will be inserted after every table except the last.
add_table(.docx, tables, titles = NA)
| .docx | An officer object |
|---|---|
| tables | A list of tables. |
| titles | A list of titles. Must be either NA or the length of tables. If NA, tables will be titles 'Table 1', 'Table 2', ... |