all_unique.RdChecking if all values are unique can be a good step in QC to ensure entries are not duplicated. If passed a list, the input is first flattened (which may result in type casting).
all_unique(vec)
| vec | A vector or list. |
|---|
#> [1] TRUE#> [1] FALSE#> [1] TRUE