knitthis.RdThis is a convenient alternative to using the knit button when you want to specify additional arguments such as output directory.
knitthis(output_dir = "documents", ...)
| output_dir | The output directory, as used in |
|---|---|
| ... | Additional arguments to pass to |
if (FALSE) { # This command will knit the Rmd file that is currently open into the directory R. knitthis("R") # Assuming the open file is data_prep.Rmd, this would be equivalent to running: rmarkdown::render(".../data_prep.Rmd", output_dir = ".../R") }